@@ -1,24 +1,11 @@
-/***********************************************************************
- *
- * Copyright (C) 2007-2009 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2007-2015 Graeme Gott <graeme@gottcode.org>
 
-#ifndef THEME_H
-#define THEME_H
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
+
+#ifndef CUTEMAZE_THEME_H
+#define CUTEMAZE_THEME_H
 
 #include <QPixmap>
 #include <QString>
@@ -28,12 +15,13 @@ class QSvgRenderer;
 class Theme
 {
 public:
-	Theme();
+	explicit Theme();
 	~Theme();
 
 	QStringList available() const;
 	void load(const QString& name);
 	void scale(int unit);
+	void setDevicePixelRatio(int ratio);
 
 	enum Element {
 		Background,
@@ -58,6 +46,7 @@ private:
 	void cache(const QString& element, QPixmap& pixmap, const QRect& bounds, int angle = 0) const;
 	QString findFile(const QString& theme, const QString& file) const;
 
+private:
 	QStringList m_locations;
 	QSvgRenderer* m_renderer;
 	QPixmap m_pixmap[TotalElements];
@@ -65,6 +54,7 @@ private:
 	QPixmap m_pixmap_corner[15];
 	QPixmap m_pixmap_wall[2];
 	int m_unit;
+	int m_ratio;
 };
 
-#endif // THEME_H
+#endif // CUTEMAZE_THEME_H
